
/*
 * Copyright (c) Developers of JMST
 * Redistributable and modifiable. Please see license.readme for details.
 *
 * ammendment history
 * <date>			<changed by>		<summary of changes>
 * 25 August 2004	Jonee Ryan Ty		First documented history
 *
 */
 
import java.awt.Color;
import java.awt.Point;

import java.util.Vector;
import java.util.Enumeration;

 
public class GNode
{
	public int 		x, y;				// upper left coordinate of node
	public Color nodeColor;
				
				// data structure containers
	public Vector 	edges,				// edges connected to this node
					nodes;				// nodes connected to this by lines
	
	public boolean 	ndeIsIncluded;		// if included perhaps in a tree
	public Tree whereIncluded;			// used for kruskal's mst
			
	/**
	 * GNode constructor
	 * @param x, y upper left coordinates of the box enclosing 
	 * the circle representing this node.
	 * @param c color associated with this node
	 */	
	public GNode(int x, int y, Color c) {
		this.x = x;
		this.y = y;
		
		ndeIsIncluded = false;
		
		edges = new Vector();
		nodes = new Vector();
		
		nodeColor = c;
	}
	
	/**
	 * Includes a reference to an edge incident to this node
	 * @param new edge that is recently connected to this node.
	 */	
	public void addEdge(Edge add) {
		edges.add(add);
	}
	
	/**
	 * Removes a reference to an edge to this node.
	 * @param the edge to remove reference with
	 */	
	public void removeEdge(Edge rem) {
		edges.remove(rem);
		edges.trimToSize();
		
		System.gc();
	}			

	/**
	 * Add a reference to a new node that is recently connected 
	 * by an edge to this node.
	 * @param add the node recently connected with this node
	 */	 
	public void addNode(GNode add) {
		nodes.add(add);
	}
	
	/**
	 *Removes a reference to a recently disconnected node.
	 */	
	public void removeNode(GNode rem) {
		nodes.remove(rem);
		nodes.trimToSize();
		
		System.gc();
	}
	
	/**
	 * determines wether this node is connected to another node
	 * @return true if this node is connected by an edge 
	 * to param false otherwise
	 */	 
	public boolean isConnectedToNode(GNode nde) {
		return nodes.contains(nde);
	}
	
	/**
	 * determines wether this node is connected to an edge
	 * @return true if edg is connected to this node else otherwise
	 */	 
	public boolean isConnectedToEdge(Edge edg) {
		return edges.contains(edg);
	}
		
} //##30
